Uses of Enum Class
io.jooby.trpc.TrpcErrorCode
Packages that use TrpcErrorCode
-
Uses of TrpcErrorCode in io.jooby.trpc
Methods in io.jooby.trpc that return TrpcErrorCodeModifier and TypeMethodDescriptionstatic TrpcErrorCodeTrpcErrorCode.of(io.jooby.StatusCode status) Resolves the closest tRPC error code for a given Jooby HTTP status code.static TrpcErrorCodeReturns the enum constant of this class with the specified name.static TrpcErrorCode[]TrpcErrorCode.values()Returns an array containing the constants of this enum class, in the order they are declared.Constructors in io.jooby.trpc with parameters of type TrpcErrorCodeModifierConstructorDescriptionTrpcException(String procedure, TrpcErrorCode code) Constructs a new tRPC exception without an underlying cause.TrpcException(String procedure, TrpcErrorCode code, Throwable cause) Constructs a new tRPC exception using a specific tRPC error code.